# -*- coding: utf-8 -*-

from __future__ import (unicode_literals, division, absolute_import, print_function)

__license__ = 'GPL 3'
__copyright__ = '2011, Tomasz Długosz <tomek3d@gmail.com>'
__docformat__ = 'restructuredtext en'

# import random
import re
import urllib2
from contextlib import closing

from lxml import html

from PyQt4.Qt import QUrl

from calibre import browser
from calibre.gui2 import open_url
from calibre.gui2.store import StorePlugin
from calibre.gui2.store.basic_config import BasicStoreConfig
from calibre.gui2.store.search_result import SearchResult
from calibre.gui2.store.web_store_dialog import WebStoreDialog

class NextoStore(BasicStoreConfig, StorePlugin):

    def open(self, parent=None, detail_item=None, external=False):
        pid = '155711'
        # Use Kovid's affiliate id 30% of the time.
        #if random.randint(1, 10) in (1, 2, 3):
        #    pid = '21000000000352583'
        
        url = 'http://www.nexto.pl/?pid=' + pid
        detail_url = None

        if detail_item:
            book_id = re.search(r'p[0-9]*\.xml\Z', detail_item)
            book_id = book_id.group(0).replace('.xml','').replace('p','')
            if book_id:
                detail_item = 'http://www.nexto.pl/rf/pr?p=' + book_id + '&pid=' + pid

        if external or self.config.get('open_external', False):
            open_url(QUrl(url_slash_cleaner(detail_url if detail_url else url)))
        else:
            d = WebStoreDialog(self.gui, url, parent, detail_item)
            d.setWindowTitle(self.name)
            d.set_tags(self.config.get('tags', ''))
            d.exec_()

    def search(self, query, max_results=10, timeout=60):
        url = 'http://www.nexto.pl/szukaj.xml?search-clause=' + urllib2.quote(query) + '&scid=1015'
        
        br = browser()
        
        counter = max_results
        with closing(br.open(url, timeout=timeout)) as f:
            doc = html.fromstring(f.read())
            for data in doc.xpath('//ul[@class="productslist"]/li'):
                if counter <= 0:
                    break
                
                id = ''.join(data.xpath('.//div[@class="cover_container"]/a[1]/@href'))
                if not id:
                    continue

                price = ''.join(data.xpath('.//strong[@class="nprice"]/text()'))

                cover_url = ''.join(data.xpath('.//img[@class="cover"]/@src'))
                title = ''.join(data.xpath('.//a[@class="title"]/text()'))
                author = ', '.join(data.xpath('.//span[@class="contributers-line"]/a/text()'))

                formats = ', '.join(data.xpath('.//ul[@class="formats_available"]/li//b/text()'))
                DrmFree = re.search(r'bez.DRM', formats)
                
                counter -= 1
                
                s = SearchResult()
                s.cover_url = cover_url
                s.title = title.strip()
                s.author = author.strip()
                s.price = price
                s.detail_item = id.strip()
                s.drm = SearchResult.DRM_UNLOCKED if DrmFree else SearchResult.DRM_LOCKED
                s.formats = formats
                
                yield s
